@@ -74,8 +74,6 @@ static void gff_load_outline (GnomeFontFace *face, gint glyph);
 static void gf_pso_print_sized (GnomeFontPsObject *pso, const guchar *text, gint size);
 static void gf_pso_sprintf (GnomeFontPsObject * pso, 
 			    const gchar * format, ...);
-static gint gf_pso_print_double (GnomeFontPsObject *pso, const gchar *format,
-				 gdouble x);
 
 static void gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject * pso, gint size);
 
@@ -848,7 +846,7 @@ gnome_font_face_lookup_default (GnomeFontFace * face, gint unicode)
 }
 
 gboolean
-gff_load (GnomeFontFace *face)
+gnome_font_face_load (GnomeFontFace *face)
 {
 	FT_Face ft_face;
 	FT_Error ft_result;
@@ -1500,22 +1498,6 @@ gf_pso_sprintf (GnomeFontPsObject *pso, const gchar * format, ...)
 	g_free (text);
 }
 
-/* Allowed conversion specifiers are 'e', 'E', 'f', 'F', 'g' and 'G'. */
-static gint   
-gf_pso_print_double (GnomeFontPsObject *pso, const gchar *format, gdouble x)
-{
- 	gchar *text;
-
-	text = g_new (gchar, G_ASCII_DTOSTR_BUF_SIZE);
-	g_ascii_formatd (text, G_ASCII_DTOSTR_BUF_SIZE, format, x);
-
-	gf_pso_print_sized (pso, text, strlen (text));
-	g_free (text);
-
-	return GNOME_PRINT_OK;
-}
-
-
 static void
 gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject *pso, gint size)
 {
