@@ -35,6 +35,8 @@
 #include <pango/pangoft2.h>
 
 /**
+ * is_gnome_print_key :
+ * 
  * We want to make sure that the Pango objects that get used
  * are the ones we create or there can be subtle bugs, so we
  * use a flag in gnome-print data to track this. It might be
@@ -287,13 +289,16 @@ gnome_print_pango_glyph_string (GnomePrintContext *gpc, PangoFont *font, PangoGl
 	
 	for (i = 0; i < glyphs->num_glyphs; i++) {
 		PangoGlyphInfo *gi = &glyphs->glyphs[i];
-		int x = x_off + gi->geometry.x_offset;
-		int y = gi->geometry.y_offset;
 
-		gnome_glyphlist_moveto (glyph_list,
-					(gdouble) x / PANGO_SCALE, (gdouble) y / PANGO_SCALE);
-		gnome_glyphlist_glyph (glyph_list, gi->glyph);
-		
+		if (gi->glyph) {
+			int x = x_off + gi->geometry.x_offset;
+			int y = gi->geometry.y_offset;
+			
+			gnome_glyphlist_moveto (glyph_list,
+						(gdouble) x / PANGO_SCALE, (gdouble) y / PANGO_SCALE);
+			gnome_glyphlist_glyph (glyph_list, gi->glyph);
+		}
+			
 		x_off += glyphs->glyphs[i].geometry.width;
 	}
 
