@@ -169,7 +169,9 @@ gp_transport_cups_construct (GnomePrintTransport *gp_transport)
 	}
 	
 	transport->printer = printer;
-	transport->temp_file = g_strdup ("/tmp/gnome-print-cups-XXXXXX");
+	transport->temp_file = g_build_filename(g_get_tmp_dir (), 
+						"gnome-print-cups-XXXXXX", 
+						NULL);
 
 	return GNOME_PRINT_OK;
 }
