@@ -34,11 +34,14 @@
 #include <libgnomeprint/gpa/gpa-printer.h>
 #include <libgnomeprint/gpa/gpa-option.h>
 #include <libgnomeprint/gpa/gpa-settings.h>
+#include <libgnomeprint/gpa/gpa-state.h>
 #include <libgnomeprint/gpa/gpa-utils.h>
 
-#include <cups/cups.h>
 #include <cups/ppd.h>
 
+#include <libgnomecups/gnome-cups-init.h>
+#include <libgnomecups/gnome-cups-printer.h>
+
 #include "libgnomeprint/gnome-print-i18n.h"
 
 /* Argument order: id, name */
@@ -138,28 +141,15 @@ xmlChar *model_unknown_xml_template =
 "  </Options>"
 "</Model>";
 
-G_MODULE_EXPORT void gpa_module_load_data (GPAPrinter *printer);
-
-static GPANode *
-gpa_model_new_from_xml (char *string)
+struct GnomePrintCupsNewPrinterCbData
 {
-	GPANode *model;
-	xmlNodePtr root;
-	xmlDocPtr doc;
-	
-	doc = xmlParseDoc (string);
-	if (!doc) {
-		g_warning ("Could not parse model xml");
-		return NULL;
-	}
-	
-	root = doc->xmlRootNode;
-	model = gpa_model_new_from_tree (root);
-	
-	xmlFreeDoc (doc);
-	
-	return model;
-}
+	GPAList *list;
+	char *path;
+};
+
+G_MODULE_EXPORT void gpa_module_load_data (GPAPrinter *printer);
+static void printer_added_cb (const char *name, struct GnomePrintCupsNewPrinterCbData *data);
+static void printer_gone_cb (GnomeCupsPrinter *printer, GPAList *list);
 
 static char *
 get_paper_text (ppd_file_t *ppd, ppd_size_t *size)
@@ -373,7 +363,7 @@ get_model (const gchar *printer, ppd_file_t *ppd)
 	}
 
 	xml = g_strdup_printf (model_xml_template, id, ppd->nickname);
-	model = gpa_model_new_from_xml (xml);
+	model = gpa_model_new_from_xml_str (xml);
 	g_free (xml);
 
 	output = gpa_node_lookup (model, "Options.Output");
@@ -407,7 +397,7 @@ get_model_no_ppd (const gchar *printer)
 		return GPA_MODEL (model);
 
 	xml = g_strdup_printf (model_unknown_xml_template, "Cups-unknown-unknown");
-	model = gpa_model_new_from_xml (xml);
+	model = gpa_model_new_from_xml_str (xml);
 	g_free (xml);
 
 	media  = gpa_node_lookup (model, "Options.Output.Media");
@@ -423,13 +413,12 @@ get_model_no_ppd (const gchar *printer)
 }
 
 static gboolean
-append_printer (GPAList *printers_list, const char *name, 
+append_printer (GPAList *printers_list, GnomeCupsPrinter *cupsprinter,
 		gboolean is_default, const gchar *path)
 {
-	GPANode *printer  = NULL;
 	gboolean retval = FALSE;
-
-	printer = gpa_printer_new_stub (name, name, path);
+	const char *name = gnome_cups_printer_get_name (cupsprinter);
+	GPANode *printer  = gpa_printer_new_stub (name, name, path);
 
 	if (printer != NULL && gpa_node_verify (printer)) {
 		gpa_list_prepend (printers_list, printer);
@@ -438,6 +427,9 @@ append_printer (GPAList *printers_list, const char *name,
 			gpa_module_load_data (GPA_PRINTER (printer));
 		}
 		retval = TRUE;
+		g_signal_connect (cupsprinter, "gone",
+				  G_CALLBACK (printer_gone_cb),
+				  printers_list);
 	}
 
 	if (retval == FALSE) {
@@ -448,50 +440,69 @@ append_printer (GPAList *printers_list, const char *name,
 	return retval;
 }
 
+static 	GModule *handle = NULL;
+
 static void
 gnome_print_cups_printer_list_append (gpointer printers_list, 
 				      const gchar *path)
 {
 	/* const gchar *def = cupsGetDefault(); 
 	   not reliable, dests[i].is_default used instead */
-        cups_dest_t *dests = NULL;
-	gint num_printers;
-	gint i;
+        GList *printers = NULL;
+	GList *link;
+	struct GnomePrintCupsNewPrinterCbData *data;
 
 	g_return_if_fail (printers_list != NULL);
 	g_return_if_fail (GPA_IS_LIST (printers_list));
+
+	/* make ourselves resident */
+	if (!handle) 
+		handle = g_module_open (path, G_MODULE_BIND_LAZY);
+
+	gnome_cups_init (NULL);
+	data = g_new0 (struct GnomePrintCupsNewPrinterCbData, 1);
+	data->list = printers_list;
+	data->path = g_strdup (path);
+	gnome_cups_printer_new_printer_notify_add ((GnomeCupsPrinterAddedCallback) printer_added_cb, data);
 	
-	num_printers = cupsGetDests(&dests);
+	printers = gnome_cups_get_printers ();
 	
-	for (i = 0; i < num_printers; i ++) {
-		if (dests[i].instance == NULL)
+	for (link = printers; link; link = link->next) {
+		const char *name;
+		GnomeCupsPrinter *printer;
+
+		name = link->data;
+		printer = gnome_cups_printer_get (name);
+
+		if (printer) {
 			append_printer (GPA_LIST (printers_list),
-					dests[i].name, 
-					dests[i].is_default,
+					printer,
+					gnome_cups_printer_get_is_default (printer),					
 					path);
+			g_object_unref (G_OBJECT (printer));
+		}
 	}
 
-	cupsFreeDests (num_printers, dests);
+	gnome_cups_printer_list_free (printers);
 	
 	return;
 }
 
 static void
 gnome_print_cups_adjust_settings (GPASettings * settings,
-				  int num_options,
-				  cups_option_t *options)
+				  GnomeCupsPrinter *printer)
 {
-	int i;
-	const char *value;
+	char *value;
 	
-	value = cupsGetOption ("PageSize", num_options, options);
+	value = gnome_cups_printer_get_option_value (printer, "PageSize");
 	if (value != NULL) {
 		gpa_node_set_path_value (GPA_NODE (settings),
 					 "Output.Media.PhysicalSize", 
 					 value);
 	}
+	g_free (value);
 
-	value = cupsGetOption ("sides", num_options, options);
+	value = gnome_cups_printer_get_option_value (printer, "PageSize");
 	if (value != NULL) {
 		if (strcmp("two-sided-long-edge", value) == 0) {
 			gpa_node_set_path_value (GPA_NODE (settings),
@@ -515,11 +526,130 @@ gnome_print_cups_adjust_settings (GPASettings * settings,
 						 "false");
 		}
 	}
+	g_free (value);
 /* 	for (i=0; i < num_options; i++) { */
 /* 		g_print ("Option %s = %s\n", options[i].name, options[i].value); */
 /* 	} */
 }
 
+static void
+attributes_changed_cb (GnomeCupsPrinter *cupsprinter,
+		       GPAPrinter     *printer)
+{
+	GPANode *state;
+	GPANode *printerstate;
+	GPANode *jobcount;
+	const char *str;
+	char *len_str;
+
+	state = gpa_printer_get_state (printer);
+	printerstate = gpa_node_get_child_from_path (state, "PrinterState");
+	if (printerstate == NULL) {
+		printerstate = GPA_NODE (gpa_state_new ("PrinterState"));
+		gpa_node_attach (state, printerstate);
+	}
+	str = gnome_cups_printer_get_state_name (cupsprinter);
+	gpa_node_set_value (printerstate, str);
+
+	jobcount = gpa_node_get_child_from_path (state, "QueueLength");
+	if (jobcount == NULL) {
+		jobcount = GPA_NODE (gpa_state_new ("QueueLength"));
+		gpa_node_attach (state, jobcount);
+	}
+	len_str = g_strdup_printf ("%d", gnome_cups_printer_get_job_count (cupsprinter));
+	gpa_node_set_value (jobcount, len_str);
+	g_free (len_str);
+}
+
+static void
+add_printer_location (GnomeCupsPrinter *cupsprinter,
+		      GPAPrinter       *printer)
+{
+	GPANode *state;
+	GPANode *location;
+	const char *str;
+
+	state = gpa_printer_get_state (printer);
+	location = gpa_node_get_child_from_path (state, "Location");
+	if (location == NULL) {
+		location = GPA_NODE (gpa_state_new ("Location"));
+		gpa_node_attach (state, location);
+	}
+	str = gnome_cups_printer_get_location (cupsprinter);
+	gpa_node_set_value (location, str);
+}
+
+static void
+printer_added_cb (const char *name, struct GnomePrintCupsNewPrinterCbData *data)
+{
+	GPANode *node;
+	GnomeCupsPrinter *printer;
+
+	if ((node = gpa_printer_get_by_id (name)) != NULL) {
+		gpa_node_unref (node);
+		return;
+	}
+
+	printer = gnome_cups_printer_get (name);
+	if (printer != NULL) {
+		append_printer (data->list, printer, FALSE, data->path);
+		g_object_unref (printer);
+	}
+	else
+		g_warning ("Printer %s does not exist!", name);
+	
+}
+
+static void
+printer_gone_cb (GnomeCupsPrinter *printer, GPAList *list)
+{
+	const char *name = gnome_cups_printer_get_name (printer);
+	GPANode *child;
+	child = gpa_node_get_child (GPA_NODE (list), NULL);
+	while (child) {
+		if (GPA_NODE_ID_COMPARE (child, name))
+			break;
+		child = gpa_node_get_child (GPA_NODE (list), child);
+	}
+	g_return_if_fail (child != NULL);
+	gpa_node_detach (child);
+}
+
+static void
+start_polling (GPAPrinter *printer)
+{
+	GnomeCupsPrinter *cupsprinter;
+
+	cupsprinter = gnome_cups_printer_get (printer->name);
+	attributes_changed_cb (cupsprinter, printer);
+	g_signal_connect_object (cupsprinter, "attributes-changed", 
+				 G_CALLBACK (attributes_changed_cb), printer, 0);
+}
+
+static void
+stop_polling (GPAPrinter *printer)
+{
+	GnomeCupsPrinter *cupsprinter;
+
+	cupsprinter = gnome_cups_printer_get (printer->name);
+	g_signal_handlers_disconnect_by_func (cupsprinter,
+					      G_CALLBACK (attributes_changed_cb),
+					      printer);
+	/* Unref twice since _get refs itself */
+	g_object_unref (G_OBJECT (cupsprinter));
+	g_object_unref (G_OBJECT (cupsprinter));
+}
+
+void gpa_module_polling (GPAPrinter *printer, gboolean polling);
+G_MODULE_EXPORT void gpa_module_polling (GPAPrinter *printer,
+					 gboolean polling)
+{
+	if (polling)
+		start_polling (printer);
+	else
+		stop_polling (printer);
+}
+
 
 /*  ------------- GPA load_data ------------- */
 
@@ -527,23 +657,23 @@ G_MODULE_EXPORT void gpa_module_load_data (GPAPrinter *printer)
 {
 	GPANode *settings = NULL;
 	GPAModel *model    = NULL;
-	char *filename     = NULL;
 	const char *name   = printer->name;
 	ppd_file_t *ppd    = NULL;
 	gboolean success   = FALSE;
-	cups_dest_t *dests = NULL;
-	gint num_printers;
-	gint i;
-
+	GnomeCupsPrinter *cupsprinter;
+	
 	if (printer->is_complete)
 		return;
 
-	filename = g_strdup (cupsGetPPD (name));
-	ppd = ppdOpenFile (filename);
+	cupsprinter = gnome_cups_printer_get (printer->name);
 
-	if (ppd != NULL) {
-		model = get_model (name, ppd);
-	} else {
+	if (cupsprinter) {
+		ppd = gnome_cups_printer_get_ppd (cupsprinter);
+		if (ppd) {
+			model = get_model (name, ppd);
+		}
+	}
+	if (!ppd) {
 		g_warning ("The ppd file for the CUPS printer %s "
 			   "could not be loaded.", name);
 		model = get_model_no_ppd (name);
@@ -555,52 +685,33 @@ G_MODULE_EXPORT void gpa_module_load_data (GPAPrinter *printer)
 	if (settings == NULL)
 		goto gpa_module_load_data_exit;
 
-	num_printers = cupsGetDests(&dests);
-	for (i = 0; i < num_printers; i ++) {
-		if ((dests[i].instance == NULL) && 
-		    (strcmp (dests[i].name, name) == 0)) {
-			gnome_print_cups_adjust_settings 
-				(GPA_SETTINGS (settings),
-				 dests[i].num_options,
-				 dests[i].options);
-			break;
-		}
-	}
+	gnome_print_cups_adjust_settings (GPA_SETTINGS (settings), cupsprinter);
 
 	success = gpa_printer_complete_stub (printer, model, 
 					     GPA_SETTINGS (settings));
 
+	add_printer_location (cupsprinter, printer);
+	attributes_changed_cb (cupsprinter, printer);
+
 	/* Do we have to add any further instances */
-	{
-		for (i = 0; i < num_printers; i ++) {
-			if ((dests[i].instance != NULL) && 
-			    (strcmp (dests[i].name, name) == 0)) {
-				char *id = g_strdup_printf ("SetIdFromCups-%s",
-							    dests[i].instance);
-				settings = gpa_settings_new (model, 
-							     dests[i].instance,
-							     id);
-				g_free (id);
-				id = NULL;
-				if (settings != NULL) {
-					gnome_print_cups_adjust_settings 
-						(GPA_SETTINGS (settings),
-						 dests[i].num_options,
-						 dests[i].options);
-					gpa_list_prepend 
-						(GPA_NODE (printer->settings), 
-						 GPA_NODE (settings));
-					GPA_SETTINGS(settings)->printer 
-						= gpa_reference_new 
-						(GPA_NODE (printer), 
-						 "Printer");
-				}
-			}
-		}
-		
-	}
+	/* FIXME - punt on instance bits for now */
+/* 	{ */
+/* 		char *id = g_strdup_printf ("SetIdFromCups-%s", name); */
+/* 		settings = gpa_settings_new (model, name, id); */
+/* 		g_free (id); */
+/* 		id = NULL; */
+/* 		if (settings != NULL) { */
+/* 			gnome_print_cups_adjust_settings (GPA_SETTINGS (settings), */
+/* 							  cupsprinter); */
+/* 			gpa_list_prepend (GPA_NODE (printer->settings), */
+/* 					  GPA_NODE (settings)); */
+/* 			GPA_SETTINGS (settings)->printer */
+/* 				= gpa_reference_new (GPA_NODE (printer), "Printer"); */
+/* 		} */
+/* 	} */
 
  gpa_module_load_data_exit:
+	g_object_unref (cupsprinter);
 	if (success == FALSE) {
 		g_warning ("The data for the CUPS printer %s "
 			   "could not be loaded.", name);
@@ -613,12 +724,8 @@ G_MODULE_EXPORT void gpa_module_load_data (GPAPrinter *printer)
 
 	if (ppd) {
 		ppdClose (ppd);
-		unlink (filename);
 	}
 
-	if (filename)
-		g_free (filename);
-	
 /* 	gpa_utils_dump_tree (GPA_NODE (printer),5); */
 	return;
 }
