@@ -33,10 +33,10 @@
  *
  */
 
-/* $Id: ttcr.c,v 1.2 2004/07/21 16:42:25 jody Exp $ */
+/* $Id: ttcr.c,v 1.4 2004/09/10 18:59:06 jody Exp $ */
 /* @(#)ttcr.c 1.7 03/01/08 SMI */
 
-/**
+/*
  * @file ttcr.c
  * @brief TrueTypeCreator method implementation
  * @author Alexander Gelfenbain <adg@sun.com>
@@ -696,7 +696,7 @@ static int GetRawData_glyf(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
     /* uint16 curID = 0;    */               /* to check if glyph IDs are sequential and start from zero */
     byte *p;
 
-    *ptr = 0;
+    *ptr = NULL;
     *len = 0;
     *tag = 0;
 
@@ -821,7 +821,7 @@ static int GetRawData_name(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
     int stringLen = 0;
     byte *p1, *p2;
 
-    *ptr = 0;
+    *ptr = NULL;
     *len = 0;
     *tag = 0;
 
@@ -886,7 +886,7 @@ static int GetRawData_name(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32
 static int GetRawData_post(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
 {
     tdata_post *p = (tdata_post *) _this->data;
-    byte *post = 0;
+    byte *post = NULL;
     uint32 postLen = 0;
     int ret;
 
@@ -965,12 +965,12 @@ TrueTypeTable *TrueTypeTableNew(uint32 tag,
         pdata->ptr = ttmalloc(nbytes); 
         memcpy(pdata->ptr, ptr, nbytes);
     } else {
-        pdata->ptr = 0;
+        pdata->ptr = NULL;
     }
 
     table->tag = 0;
     table->data = pdata;
-    table->rawdata = 0;
+    table->rawdata = NULL;
 
     return table;
 }
@@ -1006,7 +1006,7 @@ TrueTypeTable *TrueTypeTableNew_head(uint32 fontRevision,
 
     table->data = (void *) ptr;
     table->tag = T_head;
-    table->rawdata = 0;
+    table->rawdata = NULL;
 
     return table;
 }
@@ -1038,7 +1038,7 @@ TrueTypeTable *TrueTypeTableNew_hhea(int16  ascender,
     
     table->data = (void *) ptr;
     table->tag = T_hhea;
-    table->rawdata = 0;
+    table->rawdata = NULL;
 
     return table;
 }
@@ -1049,10 +1049,10 @@ TrueTypeTable *TrueTypeTableNew_loca(void)
     table->data = smalloc(sizeof(tdata_loca));
 
     ((tdata_loca *)table->data)->nbytes = 0;
-    ((tdata_loca *)table->data)->ptr = 0;
+    ((tdata_loca *)table->data)->ptr = NULL;
 
     table->tag = T_loca;
-    table->rawdata = 0;
+    table->rawdata = NULL;
 
     return table;
 }
@@ -1067,7 +1067,7 @@ TrueTypeTable *TrueTypeTableNew_maxp(byte *maxp, int size)
     }
     
     table->tag = T_maxp;
-    table->rawdata = 0;
+    table->rawdata = NULL;
 
     return table;
 }
@@ -1082,7 +1082,7 @@ TrueTypeTable *TrueTypeTableNew_glyf(void)
     listSetElementDtor(l, FreeGlyphData);
 
     table->data = l;
-    table->rawdata = 0;
+    table->rawdata = NULL;
     table->tag = T_glyf;
 
     return table;
@@ -1100,7 +1100,7 @@ TrueTypeTable *TrueTypeTableNew_cmap(void)
     
     table->data = (table_cmap *) cmap;
 
-    table->rawdata = 0;
+    table->rawdata = NULL;
     table->tag = T_cmap;
 
     return table;
@@ -1146,7 +1146,7 @@ TrueTypeTable *TrueTypeTableNew_name(int n, NameRecord *nr)
     }
 
     table->data = l;
-    table->rawdata = 0;
+    table->rawdata = NULL;
     table->tag = T_name;
 
     return table;
@@ -1170,10 +1170,10 @@ TrueTypeTable *TrueTypeTableNew_post(uint32 format,
     post->underlinePosition = underlinePosition;
     post->underlineThickness = underlineThickness;
     post->isFixedPitch = isFixedPitch;
-    post->ptr = 0;
+    post->ptr = NULL;
 
     table->data = post;
-    table->rawdata = 0;
+    table->rawdata = NULL;
     table->tag = T_post;
 
     return table;
@@ -1209,11 +1209,11 @@ int GetRawData(TrueTypeTable *_this, byte **ptr, uint32 *len, uint32 *tag)
     assert(len != 0);
     assert(tag != 0);
 
-    *ptr = 0; *len = 0; *tag = 0;
+    *ptr = NULL; *len = 0; *tag = 0;
 
     if (_this->rawdata) {
         free(_this->rawdata);
-        _this->rawdata = 0;
+        _this->rawdata = NULL;
     }
 
     for(i=0; i < sizeof(vtable2)/sizeof(*vtable2); i++) {
@@ -1369,7 +1369,7 @@ void nameAdd(TrueTypeTable *table, NameRecord *nr)
                
 static TrueTypeTable *FindTable(TrueTypeCreator *tt, uint32 tag)
 {
-    if (listIsEmpty(tt->tables)) return 0;
+    if (listIsEmpty(tt->tables)) return NULL;
 
     listToFirst(tt->tables);
 
@@ -1379,7 +1379,7 @@ static TrueTypeTable *FindTable(TrueTypeCreator *tt, uint32 tag)
         }
     } while (listNext(tt->tables));
 
-    return 0;
+    return NULL;
 }
 
 /* This function processes all the tables and synchronizes them before creating
